@@ -25,11 +25,16 @@ video_audience_retention <- function(videoId = NULL, audienceType = "ORGANIC", .
     stop("Audience Type must be one of the following: ORGANIC, AD_INSTREAM, AD_INDISPLAY")
   }
   
-  temp <- analytics_request(dimensions = "elapsedVideoTimeRatio",
-                            metrics = "audienceWatchRatio",
-                            maxResults = NULL,
-                            sort="elapsedVideoTimeRatio",
-                            filters = paste0("video==", videoId,
-                                             ";audienceType==", audienceType), ...)
-  return(temp)
+  results <- data.frame()
+  for(i in 1:length(videoId)) {
+    temp <- analytics_request(dimensions = "elapsedVideoTimeRatio",
+                              metrics = "audienceWatchRatio",
+                              maxResults = NULL,
+                              sort="elapsedVideoTimeRatio",
+                              filters = paste0("video==", videoId[i],
+                                               ";audienceType==", audienceType), ...)
+    
+    results <- dplyr::bind_rows(results, error_checking(temp, videoId[i], "video"))
+  }
+  return(results)
 }
\ No newline at end of file
