@@ -17,8 +17,15 @@
 #' } 
 
 video_stats <- function(videoId = NULL, ...) {
-  temp <- analytics_request(filters = paste0("video==", videoId), ...)
-  return(temp)
+  
+  results <- data.frame()
+  for(i in 1:length(videoId)) {
+    temp <- analytics_request(filters = paste0("video==", videoId[i]), ...)
+    
+    results <- dplyr::bind_rows(results, error_checking(temp, videoId[i], "video"))
+  }
+  
+  return(results)
 }
 
 
@@ -39,8 +46,15 @@ video_stats <- function(videoId = NULL, ...) {
 #' }
 
 playlist_stats <- function(playlistId = NULL, ...) {
-  temp <- analytics_request(filters = paste0("playlist==", playlistId, ";isCurated==1"), ...)
-  return(temp)
+  
+  results <- data.frame()
+  for(i in 1:length(playlistId)) {
+    temp <- analytics_request(filters = paste0("playlist==", playlistId[i], ";isCurated==1"),
+                              ...)
+    
+    results <- dplyr::bind_rows(results, error_checking(temp, playlistId[i], "playlist"))
+  }
+  return(results)
 }
 
 
