@@ -17,9 +17,16 @@
 #' } 
 
 playlist_top_videos <- function(playlistId = NULL, ...) {
-  temp <- analytics_request(dimensions = "video",
-                            filters = paste0("playlist==", playlistId), ...)
-  return(temp)
+  
+  results <- data.frame()
+  for(i in 1:length(playlistId)) {
+    temp <- analytics_request(dimensions = "video",
+                              filters = paste0("playlist==", playlistId[i]), ...)
+    
+    results <- dplyr::bind_rows(results, error_checking(temp, playlistId[i], "playlist"))
+  }
+  
+  return(results)
 }
 
 
